==> haskell-conduit-1.3.4.1-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 conduit
version:              1.3.4.1
visibility:           public
id:                   conduit-1.3.4.1-JhpFJ1LDCkL1nAd1ht1CK3
key:                  conduit-1.3.4.1-JhpFJ1LDCkL1nAd1ht1CK3
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Streaming data processing library.
description:
    `conduit` is a solution to the streaming data problem, allowing for production,
    transformation, and consumption of streams of data in constant memory. It is an
    alternative to lazy I\/O which guarantees deterministic resource handling.

    For more information about conduit in general, and how this package in
    particular fits into the ecosystem, see [the conduit
    homepage](https://github.com/snoyberg/conduit#readme).

    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.

category:             Data, Conduit
abi:                  baec1b1c25c68ed1f61e99aaeed5f099
exposed:              True
exposed-modules:
    Conduit Data.Conduit Data.Conduit.Combinators
    Data.Conduit.Combinators.Stream Data.Conduit.Internal
    Data.Conduit.Internal.Fusion Data.Conduit.Internal.List.Stream
    Data.Conduit.Lift Data.Conduit.List

hidden-modules:
    Data.Conduit.Internal.Pipe Data.Conduit.Internal.Conduit
    Data.Conduit.Combinators.Unqualified Data.Streaming.FileRead
    Data.Streaming.Filesystem

import-dirs:          /usr/lib/ghc-8.10.4/site-local/conduit-1.3.4.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/conduit-1.3.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/conduit-1.3.4.1
hs-libraries:         HSconduit-1.3.4.1-JhpFJ1LDCkL1nAd1ht1CK3
depends:
    base-4.14.1.0 bytestring-0.10.12.0 directory-1.3.6.0
    exceptions-0.10.4 filepath-1.4.2.1
    mono-traversable-1.0.15.1-82wkAd8ObNAE4C0kkpsBAp mtl-2.2.2
    primitive-0.7.1.0-1jtn3ScaNXuKFqzzByIWfh
    resourcet-1.2.4.2-BxbS7IjbeyF7Wa1vu7rj0 text-1.2.4.1
    transformers-0.5.6.2 unix-2.7.2.2
    unliftio-core-0.2.0.1-9GVcmaajsglG88oErAZOTV
    vector-0.12.2.0-95IX5pRBJ9d1AshkFlsixP

haddock-interfaces:   /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html:         /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-1.3.4.1-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 conduit
version:              1.3.4.1
visibility:           public
id:                   conduit-1.3.4.1-DjARsxY03wZKokCcnW9ddh
key:                  conduit-1.3.4.1-DjARsxY03wZKokCcnW9ddh
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Streaming data processing library.
description:
    `conduit` is a solution to the streaming data problem, allowing for production,
    transformation, and consumption of streams of data in constant memory. It is an
    alternative to lazy I\/O which guarantees deterministic resource handling.

    For more information about conduit in general, and how this package in
    particular fits into the ecosystem, see [the conduit
    homepage](https://github.com/snoyberg/conduit#readme).

    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.

category:             Data, Conduit
abi:                  bd953f3032713575b01cdd372228c0a8
exposed:              True
exposed-modules:
    Conduit Data.Conduit Data.Conduit.Combinators
    Data.Conduit.Combinators.Stream Data.Conduit.Internal
    Data.Conduit.Internal.Fusion Data.Conduit.Internal.List.Stream
    Data.Conduit.Lift Data.Conduit.List

hidden-modules:
    Data.Conduit.Internal.Pipe Data.Conduit.Internal.Conduit
    Data.Conduit.Combinators.Unqualified Data.Streaming.FileRead
    Data.Streaming.Filesystem

import-dirs:          /usr/lib/ghc-8.10.4/site-local/conduit-1.3.4.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/conduit-1.3.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/conduit-1.3.4.1
hs-libraries:         HSconduit-1.3.4.1-DjARsxY03wZKokCcnW9ddh
depends:
    base-4.14.1.0 bytestring-0.10.12.0 directory-1.3.6.0
    exceptions-0.10.4 filepath-1.4.2.1
    mono-traversable-1.0.15.1-FduOvTaPcvADAUjsp0s2z4 mtl-2.2.2
    primitive-0.7.1.0-BzleGstbK9GCUeh5YTaiIg
    resourcet-1.2.4.2-IRCGLbQj3ZT9CjWsUFe0eL text-1.2.4.1
    transformers-0.5.6.2 unix-2.7.2.2
    unliftio-core-0.2.0.1-9GVcmaajsglG88oErAZOTV
    vector-0.12.2.0-7EbNsr7S4xfLPw9HM8zAxH

haddock-interfaces:   /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html:         /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
